Checks whether the DATACOMMONS_API_KEY environment variable has been set.
Useful for examples, tests, or conditional execution of functions requiring
authentication.
Checks whether the DATACOMMONS_API_KEY environment variable has been set.
Useful for examples, tests, or conditional execution of functions requiring
authentication.